@@ -1,20 +1,27 @@
 package MooseX::Role::Parameterized;
+BEGIN {
+  $MooseX::Role::Parameterized::AUTHORITY = 'cpan:SARTAK';
+}
+# git description: v1.03-13-gfe69c8f
+$MooseX::Role::Parameterized::VERSION = '1.04';
+# ABSTRACT: roles with composition parameters
+
 use 5.008001;
-use Moose::Role ();
+use Moose 2.0300 ();
 use Moose::Exporter;
 use Carp 'confess';
 use Moose::Util 'find_meta';
+use namespace::clean;
 
 use MooseX::Role::Parameterized::Meta::Trait::Parameterizable;
 
-our $VERSION = '1.03';
 our $CURRENT_METACLASS;
 
-sub current_metaclass { $CURRENT_METACLASS }
+sub _current_metaclass { $CURRENT_METACLASS }
 
 my $meta_lookup = sub {
     my $for = shift;
-    current_metaclass() || find_meta($for);
+    _current_metaclass() || find_meta($for);
 };
 
 Moose::Exporter->setup_import_methods(
@@ -31,7 +38,7 @@ sub parameter {
     my $caller = shift;
 
     confess "'parameter' may not be used inside of the role block"
-        if current_metaclass && current_metaclass->genitor->name eq $caller;
+        if _current_metaclass && _current_metaclass->genitor->name eq $caller;
 
     my $meta = find_meta($caller);
 
@@ -51,7 +58,7 @@ sub role (&) {
     my $role_generator = shift;
 
     confess "'role' may not be used inside of the role block"
-        if current_metaclass && current_metaclass->genitor->name eq $caller;
+        if _current_metaclass && _current_metaclass->genitor->name eq $caller;
 
     find_meta($caller)->role_generator($role_generator);
 }
@@ -80,10 +87,18 @@ sub with {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::Role::Parameterized - roles with composition parameters
 
+=head1 VERSION
+
+version 1.04
+
 =head1 SYNOPSIS
 
     package Counter;
@@ -126,11 +141,6 @@ MooseX::Role::Parameterized - roles with composition parameters
 
     with Counter => { name => 'zapped' };
 
-=head1 L<MooseX::Role::Parameterized::Tutorial>
-
-B<Stop!> If you're new here, please read
-L<MooseX::Role::Parameterized::Tutorial> for a much gentler introduction.
-
 =head1 DESCRIPTION
 
 Your parameterized role consists of two new things: parameter declarations
@@ -165,6 +175,15 @@ The benefits of using an object are similar to the benefits of using Moose. You
 get an easy way to specify lazy defaults, type constraint, delegation, and so
 on. You get to use MooseX modules.
 
+=for Pod::Coverage method parameter role with
+
+=head1 L<MooseX::Role::Parameterized::Tutorial>
+
+B<Stop!> If you're new here, please read
+L<MooseX::Role::Parameterized::Tutorial> for a much gentler introduction.
+
+=for stopwords metaobject
+
 You also get the usual introspective and intercessory abilities that come
 standard with the metaobject protocol. Ambitious users should be able to add
 traits to the parameters metaclass to further customize behavior. Please let
@@ -176,10 +195,6 @@ You must use this syntax to declare methods in the role block:
 C<< method NAME => sub { ... }; >>. This is due to a limitation in Perl. In
 return though you can use parameters I<in your methods>!
 
-=head1 AUTHOR
-
-Shawn M Moore, C<sartak@gmail.com>
-
 =head1 SEE ALSO
 
 L<http://sartak.org/2009/01/parametric-roles-in-perl-5.html>
@@ -196,13 +211,69 @@ L<http://jjnapiorkowski.typepad.com/modern-perl/2010/08/parameterized-roles-and-
 
 L<http://sartak.org/talks/yapc-asia-2009/(parameterized)-roles/>
 
+=for stopwords Joose
+
 L<https://github.com/SamuraiJack/JooseX-Role-Parameterized> - this extension ported to JavaScript's Joose
 
+=head1 AUTHOR
+
+Shawn M Moore <code@sartak.org>
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2010 Infinity Interactive
+This software is copyright (c) 2008 by Shawn M Moore.
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 CONTRIBUTORS
+
+=over 4
+
+=item *
+
+Chris Weyl <rsrchboy@cpan.org>
+
+=item *
+
+Csson <erik.carlsson@live.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Oliver Charles <oliver.g.charles@googlemail.com>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=item *
+
+Robert 'phaylon' Sedlacek <rs@474.at>
+
+=item *
+
+Todd Hepler <thepler@employees.org>
+
+=item *
+
+Yuval Kogman <nothingmuch@woobling.org>
+
+=back
 
 =cut
